---
name: Bug report
about: Bug report
title: ''
labels: ''
assignees: ''

---

**Description**

Brief description of bug. Include copy-paste of error message details, or table of error data, if available.

**To Reproduce**

Steps to reproduce the behavior, e.g.:

1. Go to '...'
2. Click on '...'
3. Scroll down to '...'
4. See error

**Screenshots**

If it will be helpful, add screenshots.

**Extra software info, if not already included in the Description:**

- OS (e.g., iOS, windows):
- Browser (e.g., chrome, safari):
- How you've installed Lute (Docker, python, source)
- Version: 
